Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(519)

Unified Diff: ui/file_manager/zip_archiver/cpp/volume.cc

Issue 2815063002: Rename variable, class, function, etc from libarchive to minizip. (Closed)
Patch Set: Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/file_manager/zip_archiver/cpp/volume.cc
diff --git a/ui/file_manager/zip_archiver/cpp/volume.cc b/ui/file_manager/zip_archiver/cpp/volume.cc
index 97d63803e639e7cfee20a97d61ed613397928595..1d9baa8372abe2fa48ab72c42e0848c9f5908b25 100644
--- a/ui/file_manager/zip_archiver/cpp/volume.cc
+++ b/ui/file_manager/zip_archiver/cpp/volume.cc
@@ -26,7 +26,7 @@ typedef std::map<std::string, VolumeArchive*>::const_iterator
const char kPathDelimiter[] = "/";
// size is int64_t and modification_time is time_t because this is how
// libarchive is going to pass them to us.
pp::VarDictionary CreateEntry(int64_t index,
const std::string& name,
bool is_directory,
@@ -144,7 +144,7 @@ class JavaScriptRequestor : public JavaScriptRequestorInterface {
class VolumeArchiveFactory : public VolumeArchiveFactoryInterface {
public:
virtual VolumeArchive* Create(VolumeReader* reader) {
- return new VolumeArchiveLibarchive(reader);
+ return new VolumeArchiveMinizip(reader);
}
};
« no previous file with comments | « ui/file_manager/zip_archiver/cpp/volume.h ('k') | ui/file_manager/zip_archiver/cpp/volume_archive_libarchive.h » ('j') | no next file with comments »
@@ -26,7 +26,7 @@ typedef std::map<std::string, VolumeArchive*>::const_iterator
const char kPathDelimiter[] = "/";
// size is int64_t and modification_time is time_t because this is how
-// libarchive is going to pass them to us.
+// minizip is going to pass them to us.
pp::VarDictionary CreateEntry(int64_t index,
const std::string& name,

Powered by Google App Engine
This is Rietveld 408576698